@@ -9,7 +9,7 @@ import numpy as np
 import h5py
 
 from coconet.core.feature import Feature
-from coconet.tools import run_if_not_exists
+from coconet.util import run_if_not_exists
 
 
 class CompositionFeature(Feature):
